Pillow
======

Pillow is the friendly PIL fork by `Alex Clark and Contributors <https://github.com/python-pillow/Pillow/graphs/contributors>`_. PIL is the Python Imaging Library by Fredrik Lundh and Contributors.

Pillow for enterprise is available via the Tidelift Subscription. `Learn more <https://tidelift.com/subscription/pkg/pypi-pillow?utm_source=pypi-pillow&utm_medium=docs&utm_campaign=enterprise>`_.

.. image:: https://readthedocs.org/projects/pillow/badge/?version=latest
   :target: https://pillow.readthedocs.io/?badge=latest
   :alt: Documentation Status

.. image:: https://github.com/python-pillow/Pillow/workflows/Lint/badge.svg
   :target: https://github.com/python-pillow/Pillow/actions?query=workflow%3ALint
   :alt: GitHub Actions build status (Lint)

.. image:: https://github.com/python-pillow/Pillow/workflows/Test%20Docker/badge.svg
   :target: https://github.com/python-pillow/Pillow/actions?query=workflow%3A%22Test+Docker%22
   :alt: GitHub Actions build status (Test Docker)

.. image:: https://github.com/python-pillow/Pillow/workflows/Test/badge.svg
   :target: https://github.com/python-pillow/Pillow/actions?query=workflow%3ATest
   :alt: GitHub Actions build status (Test Linux and macOS)

.. image:: https://github.com/python-pillow/Pillow/workflows/Test%20Windows/badge.svg
   :target: https://github.com/python-pillow/Pillow/actions?query=workflow%3A%22Test+Windows%22
   :alt: GitHub Actions build status (Test Windows)

.. image:: https://img.shields.io/appveyor/build/python-pillow/Pillow/main.svg?label=Windows%20build
   :target: https://ci.appveyor.com/project/python-pillow/Pillow
   :alt: AppVeyor CI build status (Windows)

.. image:: https://github.com/python-pillow/pillow-wheels/workflows/Wheels/badge.svg
   :target: https://github.com/python-pillow/pillow-wheels/actions
   :alt: GitHub Actions wheels build status (Wheels)

.. image:: https://img.shields.io/travis/com/python-pillow/pillow-wheels/main.svg?label=aarch64%20wheels
   :target: https://travis-ci.com/github/python-pillow/pillow-wheels
   :alt: Travis CI wheels build status (aarch64)

.. image:: https://codecov.io/gh/python-pillow/Pillow/branch/main/graph/badge.svg
   :target: https://codecov.io/gh/python-pillow/Pillow
   :alt: Code coverage

.. image:: https://zenodo.org/badge/17549/python-pillow/Pillow.svg
   :target: https://zenodo.org/badge/latestdoi/17549/python-pillow/Pillow
   :alt: Zenodo

.. image:: https://tidelift.com/badges/package/pypi/Pillow?style=flat
   :target: https://tidelift.com/subscription/pkg/pypi-pillow?utm_source=pypi-pillow&utm_medium=badge
   :alt: Tidelift

.. image:: https://github.com/python-pillow/Pillow/actions/workflows/tidelift.yml/badge.svg
   :target: https://github.com/python-pillow/Pillow/actions/workflows/tidelift.yml
   :alt: Tidelift Align

.. image:: https://img.shields.io/pypi/v/pillow.svg
   :target: https://pypi.org/project/Pillow/
   :alt: Latest PyPI version

.. image:: https://img.shields.io/pypi/dm/pillow.svg
   :target: https://pypi.org/project/Pillow/
   :alt: Number of PyPI downloads

Overview
========

The Python Imaging Library adds image processing capabilities to your Python interpreter.

This library provides extensive file format support, an efficient internal representation, and fairly powerful image processing capabilities.

The core image library is designed for fast access to data stored in a few basic pixel formats. It should provide a solid foundation for a general image processing tool.

.. toctree::
   :maxdepth: 2

   installation.rst
   handbook/index.rst
   reference/index.rst
   porting.rst
   about.rst
   releasenotes/index.rst
   deprecations.rst

Indices and tables
==================

* :ref:`genindex`
* :ref:`modindex`
* :ref:`search`
